@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterthebattest.h"
-#include <MailImporter/FilterTheBat>
 #include "filterimportertest.h"
+#include <MailImporter/FilterTheBat>
 #include <QTest>
 
 FilterTheBatTest::FilterTheBatTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterTheBatTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterTheBat filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -38,7 +38,7 @@ void FilterTheBatTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterTheBat filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
@@ -50,7 +50,7 @@ void FilterTheBatTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterTheBat filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
@@ -59,3 +59,5 @@ void FilterTheBatTest::canNotImportDataWhenHomeDirSelected()
 }
 
 QTEST_MAIN(FilterTheBatTest)
+
+#include "moc_filterthebattest.cpp"
