@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,8 +22,8 @@ public:
 
     void import() override;
     void importMails(const QString &maildir);
-    Q_REQUIRED_RESULT static QString defaultSettingsPath();
-    Q_REQUIRED_RESULT static QString isMailerFound();
+    [[nodiscard]] static QString defaultSettingsPath();
+    [[nodiscard]] static QString isMailerFound();
 
 private:
     void importDirContents(const QString &);
@@ -31,7 +31,6 @@ private:
     void processDirectory(const QString &path);
 
     MailImporter::MessageStatus statusFromFile(const QString &filename);
-    FilterEvolution_v3Private *const d;
+    std::unique_ptr<FilterEvolution_v3Private> const d;
 };
 }
-
