@@ -25,25 +25,25 @@ public:
     FilterSylpheed();
     ~FilterSylpheed() override;
 
-    Q_REQUIRED_RESULT static QString defaultSettingsPath();
-    Q_REQUIRED_RESULT static QString isMailerFound();
+    [[nodiscard]] static QString defaultSettingsPath();
+    [[nodiscard]] static QString isMailerFound();
 
     void import() override;
     virtual void importMails(const QString &maildir);
 
     /* return local mail dir from folderlist.xml*/
     virtual QString localMailDirPath();
-    Q_REQUIRED_RESULT virtual bool excludeFile(const QString &file);
+    [[nodiscard]] virtual bool excludeFile(const QString &file);
     virtual QString defaultInstallFolder() const;
     virtual QString markFile() const;
 
 private:
-    void importDirContents(const QString &);
-    void importFiles(const QString &);
-    void processDirectory(const QString &path);
+    MAILIMPORTER_NO_EXPORT void importDirContents(const QString &);
+    MAILIMPORTER_NO_EXPORT void importFiles(const QString &);
+    MAILIMPORTER_NO_EXPORT void processDirectory(const QString &path);
 
-    void readMarkFile(const QString &, QHash<QString, unsigned long> &);
-    MailImporter::MessageStatus msgFlagsToString(unsigned long flags);
+    MAILIMPORTER_NO_EXPORT void readMarkFile(const QString &, QHash<QString, unsigned long> &);
+    [[nodiscard]] MAILIMPORTER_NO_EXPORT MailImporter::MessageStatus msgFlagsToString(unsigned long flags);
     std::unique_ptr<FilterSylpheedPrivate> const d;
 };
 }
