@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FilterTheBatTest_H
-#define FilterTheBatTest_H
+#pragma once
 
 #include <QObject>
 
@@ -21,5 +20,3 @@ private Q_SLOTS:
     void canNotImportDataUnknowPath();
     void canNotImportDataWhenHomeDirSelected();
 };
-
-#endif // FilterTheBatTest_H
